OC.L10N.register(
    "spreed",
    {
    "Signaling server URL" : "Sender signal til tjeners URL",
    "Validate SSL certificate" : "Bekreft SSL-sertifikat",
    "Delete server" : "Slett tjener",
    "Add new server" : "Legg til ny tjener",
    "Saved" : "Lagret",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du slettet alle STUN-tjenere. Siden behovet nesten alltid er der, har en forvalgt STUN-tjener blitt lagt til.",
    "STUN server URL" : "STUN tjener URL",
    "Shared secret" : "Delt hemmelighet",
    "TURN server shared secret" : "TURN-tjeners delte hemmelighet",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "TURN server protocols" : "TURN-tjenerprotokoller",
    "New public conversation" : "Ny offentlig samtale",
    "New group conversation" : "Ny gruppesamtale",
    "New conversation …" : "Ny samtale…",
    "Participants" : "Deltakere",
    "Chat" : "Sludre",
    "Talk" : "Samtale",
    "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
    "Fullscreen (f)" : "Fullskjermsvisning (f)",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
    "Password required" : "Passord kreves",
    "Password" : "Passord",
    "Cancel" : "Avbryt",
    "Submit" : "Send inn",
    "Leave call" : "Forlat samtalen",
    "Join call" : "Ta del i samtale",
    "Share link" : "Del lenke",
    "Change password" : "Endre passord",
    "Set password" : "Velg passord",
    "Name" : "Navn",
    "Conversation name" : "Samtalenavn",
    "Rename" : "Gi nytt navn",
    "Copy link" : "Kopier lenke",
    "Conversation with {name}" : "Samtale med {name}",
    "Error occurred while setting password" : "Feil oppstod ved setting av passord",
    "Link copied!" : "Lenke kopiert!",
    "You" : "Du",
    "No messages yet, start the conversation!" : "Ingen meldinger enda, start samtalen!",
    "New message …" : "Ny melding …",
    "Send" : "Send",
    "Guest" : "Gjest",
    "[Unknown user name]" : "[Ukjent brukernavn]",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativData}, {abosluttData}",
    "Error occurred while sending message" : "Feil oppstod under foresendelse av melding",
    "Edit" : "Rediger",
    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
    "No other people in this call" : "Ingen andre personer i denne samtalen",
    "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
    "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke dette programmet.",
    "Disable video" : "Skru av video",
    "Share screen" : "Del skjerm",
    "Show your screen" : "Vis din skjerm",
    "Stop screensharing" : "Stopp skjermdeling",
    "Unmute audio (m)" : "Slå på lyd (m)",
    "Mute audio (m)" : "Slå av lyd (m)",
    "No audio" : "Ingen lyd",
    "Enable video (v)" : "Skru på video (v)",
    "Disable video (v)" : "Skru av video (v)",
    "No Camera" : "Inget kamera",
    "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "Screensharing options" : "Skjermdelingsvalg",
    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
    "Enable screensharing" : "Skru på skjermdeling",
    "moderator" : "moderator",
    "Demote from moderator" : "Fjern moderatorstatus",
    "Promote to moderator" : "Gi moderatorstatus",
    "Remove participant" : "Fjern deltaker",
    "Add participant …" : "Legg til deltager…",
    "Delete conversation" : "Slett samtale",
    "Close" : "Lukk",
    "Show screen" : "Vis skjerm",
    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
    "{participantName}'s screen" : "{participantName}'s skjerm",
    "Guest's screen" : "Gjestens skjerm",
    "Your screen" : "Din skjerm",
    "(Duration %s)" : "(Varighet %s)",
    "You attended a call with {user1}" : "Du har tatt del i en samtale med {user1}",
    "_%n guest_::_%n guests_" : ["%n gjest","%n gjester"],
    "You attended a call with {user1} and {user2}" : "Du har tatt del i en samtale med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du har tatt del i en samtale med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["én annen person","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>-rom, eller fikk et <strong>anrop</strong>",
    "Talk to %s" : "Snakk med %s",
    "_%n other guest_::_%n other guests_" : ["%n annen gjest","%n andre gjester"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
    "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
    "A group call has started" : "En gruppesamtale har blitt startet",
    "This call is password-protected" : "Denne samtalen er passordbeskyttet",
    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
    "Signaling server" : "Signaltjener",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaltjener kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signaltjener.",
    "STUN servers" : "STUN-tjener",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-tjener brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
    "TURN server" : "TURN-tjener",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-tjeneren fungerer som mellomtjener for trafikk fra deltakere bak en brannmur.",
    "(group)" : "(gruppe)",
    "and you" : "og deg",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=2; plural=(n != 1);");
